==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/Save/ts/Save_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Save</name>
    <message>
        <location filename="../Save.js" line="+77"/>
        <source>Overwrite File?</source>
        <translation>Sovrascrivere il file?</translation>
    </message>
    <message>
        <source>The file &quot;%1&quot; already exists. Do you wish to overwrite it?</source>
        <translation type="obsolete">Il file &quot;%1&quot; esiste già. Vuoi sovrascriverlo?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Il file &apos;%1&apos; esiste già. Vuoi sovrascriverlo?</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Tutti i colori personalizzati verra &apos;arrotondato&apos; per il colore più vicino fisso.</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>File Format Version Not Recommended</source>
        <translation>File formato versione non raccomandato</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file format version you are using is not recommended: &apos;%1&apos;.</source>
        <translation>La versione del formato del file in uso non è raccomandato: &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All black entities and layers will be saved as white.</source>
        <translation>Tutte le entità e livelli nere verranno salvati come bianco.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Proceed?</source>
        <translation>Procedere?</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Saved drawing:</source>
        <translation>Disegno salvato:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color. Proceed?</source>
        <translation type="obsolete">Tutti i colori personalizzati verra &apos;arrotondato&apos; per il colore più vicino fisso. Procedere?</translation>
    </message>
    <message>
        <location line="-29"/>
        <source>Saving...</source>
        <translation>Salvataggio...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Saving to file format version &apos;%1&apos;.</source>
        <translation>Salvataggio in un file formato della versione &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black entities and layers are saved as white.</source>
        <translation>Entità e livelli nere vengono salvati come bianco.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Custom colors are &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Colori personalizzati sono &apos;arrotondato&apos; per il colore più vicino fisso.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>File %1 has not been saved.</source>
        <translation>Il file %1 non è stato salvato.</translation>
    </message>
    <message>
        <source>Saved drawing: %1</source>
        <translation type="obsolete">Disegno salvato: %1</translation>
    </message>
    <message>
        <location filename="../SaveInit.js" line="+2"/>
        <source>&amp;Save</source>
        <translation>&amp;Salva</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/Save/ts/Save_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Save</name>
    <message>
        <location filename="../Save.js" line="+78"/>
        <source>Overwrite File?</source>
        <translation>Sovrascrivere il file?</translation>
    </message>
    <message>
        <source>The file &quot;%1&quot; already exists. Do you wish to overwrite it?</source>
        <translation type="obsolete">Il file &quot;%1&quot; esiste già. Vuoi sovrascriverlo?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Il file &apos;%1&apos; esiste già. Vuoi sovrascriverlo?</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Tutti i colori personalizzati verra &apos;arrotondato&apos; per il colore più vicino fisso.</translation>
    </message>
    <message>
        <location line="-4"/>
        <source>File Format Version Not Recommended</source>
        <translation>File formato versione non raccomandato</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file format version you are using is not recommended: &apos;%1&apos;.</source>
        <translation>La versione del formato del file in uso non è raccomandato: &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Custom properties will not be saved.</source>
        <translation>Le proprietà personalizzate non vengono salvate.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All black entities and layers will be saved as white.</source>
        <translation>Tutte le entità e livelli nere verranno salvati come bianco.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Proceed?</source>
        <translation>Procedere?</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Saved drawing:</source>
        <translation>Disegno salvato:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color. Proceed?</source>
        <translation type="obsolete">Tutti i colori personalizzati verra &apos;arrotondato&apos; per il colore più vicino fisso. Procedere?</translation>
    </message>
    <message>
        <location line="-32"/>
        <source>Saving...</source>
        <translation>Salvataggio...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Saving to file format version &apos;%1&apos;.</source>
        <translation>Salvataggio in un file formato della versione &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black entities and layers are saved as white.</source>
        <translation>Entità e livelli nere vengono salvati come bianco.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Custom colors are &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Colori personalizzati sono &apos;arrotondato&apos; per il colore più vicino fisso.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>File %1 has not been saved.</source>
        <translation>Il file %1 non è stato salvato.</translation>
    </message>
    <message>
        <source>Saved drawing: %1</source>
        <translation type="obsolete">Disegno salvato: %1</translation>
    </message>
    <message>
        <location filename="../SaveInit.js" line="+2"/>
        <source>&amp;Save</source>
        <translation>&amp;Salva</translation>
    </message>
</context>
</TS>
